diff --git a/core/lib/Drupal/Core/Entity/EntityStorageControllerInterface.php b/core/lib/Drupal/Core/Entity/EntityStorageControllerInterface.php
index 723e34a..645dfd9 100644
--- a/core/lib/Drupal/Core/Entity/EntityStorageControllerInterface.php
+++ b/core/lib/Drupal/Core/Entity/EntityStorageControllerInterface.php
@@ -23,12 +23,12 @@
   /**
    * Load the most recent version of an entity's field data.
    */
-  const FIELD_LOAD_CURRENT = 'FIELD_LOAD_CURRENT';
+  const LOAD_CURRENT = 'LOAD_CURRENT';
 
   /**
    * Load the version of an entity's field data specified in the entity.
    */
-  const FIELD_LOAD_REVISION = 'FIELD_LOAD_REVISION';
+  const LOAD_REVISION = 'LOAD_REVISION';
 
   /**
    * Resets the internal, static entity cache.
diff --git a/core/lib/Drupal/Core/Entity/FieldableDatabaseStorageController.php b/core/lib/Drupal/Core/Entity/FieldableDatabaseStorageController.php
index c78453c..6ce6c59 100644
--- a/core/lib/Drupal/Core/Entity/FieldableDatabaseStorageController.php
+++ b/core/lib/Drupal/Core/Entity/FieldableDatabaseStorageController.php
@@ -841,7 +841,7 @@ public function getQueryServiceName() {
    * {@inheritdoc}
    */
   protected function doLoadFieldItems($entities, $age) {
-    $load_current = $age == static::FIELD_LOAD_CURRENT;
+    $load_current = $age == static::LOAD_CURRENT;
 
     // Collect entities ids, bundles and languages.
     $bundles = array();
diff --git a/core/lib/Drupal/Core/Entity/Query/QueryInterface.php b/core/lib/Drupal/Core/Entity/Query/QueryInterface.php
index 5c32717..c24f501 100644
--- a/core/lib/Drupal/Core/Entity/Query/QueryInterface.php
+++ b/core/lib/Drupal/Core/Entity/Query/QueryInterface.php
@@ -159,15 +159,15 @@ public function accessCheck($access_check = TRUE);
    * @TODO: Once revision tables have been cleaned up, revisit this.
    *
    * @param $age
-   *   - EntityStorageControllerInterface::FIELD_LOAD_CURRENT (default): Query
+   *   - EntityStorageControllerInterface::LOAD_CURRENT (default): Query
    *     the most recent revisions only,
-   *   - EntityStorageControllerInterface::FIELD_LOAD_REVISION: Query all
+   *   - EntityStorageControllerInterface::LOAD_REVISION: Query all
    *     revisions.
    *
    * @return \Drupal\Core\Entity\Query\QueryInterface
    *   The called object.
    */
-  public function age($age = EntityStorageControllerInterface::FIELD_LOAD_CURRENT);
+  public function age($age = EntityStorageControllerInterface::LOAD_CURRENT);
 
   /**
    * Execute the query.
diff --git a/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php b/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php
index 8098849..6678a4a 100644
--- a/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php
+++ b/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php
@@ -83,7 +83,7 @@ public function addField($field, $type, $langcode) {
     for ($key = 0; $key <= $count; $key ++) {
       // If there is revision support and only the current revision is being
       // queried then use the revision id. Otherwise, the entity id will do.
-      if (!empty($entity_info['entity_keys']['revision']) && $age == EntityStorageControllerInterface::FIELD_LOAD_CURRENT) {
+      if (!empty($entity_info['entity_keys']['revision']) && $age == EntityStorageControllerInterface::LOAD_CURRENT) {
         // This contains the relevant SQL field to be used when joining entity
         // tables.
         $entity_id_field = $entity_info['entity_keys']['revision'];
@@ -251,7 +251,7 @@ protected function ensureEntityTable($index_prefix, $property, $type, $langcode,
   protected function ensureFieldTable($index_prefix, &$field, $type, $langcode, $base_table, $entity_id_field, $field_id_field) {
     $field_name = $field->getName();
     if (!isset($this->fieldTables[$index_prefix . $field_name])) {
-      $table = $this->sqlQuery->getMetaData('age') == EntityStorageControllerInterface::FIELD_LOAD_CURRENT ? FieldableDatabaseStorageController::_fieldTableName($field) : FieldableDatabaseStorageController::_fieldRevisionTableName($field);
+      $table = $this->sqlQuery->getMetaData('age') == EntityStorageControllerInterface::LOAD_CURRENT ? FieldableDatabaseStorageController::_fieldTableName($field) : FieldableDatabaseStorageController::_fieldRevisionTableName($field);
       if ($field->getCardinality() != 1) {
         $this->sqlQuery->addMetaData('simple_query', FALSE);
       }
diff --git a/core/lib/Drupal/Core/Field/Plugin/Field/FieldType/LegacyConfigFieldItem.php b/core/lib/Drupal/Core/Field/Plugin/Field/FieldType/LegacyConfigFieldItem.php
index 8c24ca9..a7008e6 100644
--- a/core/lib/Drupal/Core/Field/Plugin/Field/FieldType/LegacyConfigFieldItem.php
+++ b/core/lib/Drupal/Core/Field/Plugin/Field/FieldType/LegacyConfigFieldItem.php
@@ -101,7 +101,7 @@ public function getCacheData() {
         array($entity_id => $this->getFieldInstance()),
         $this->getLangcode(),
         &$items,
-        EntityStorageControllerInterface::FIELD_LOAD_CURRENT,
+        EntityStorageControllerInterface::LOAD_CURRENT,
       );
       call_user_func_array($callback, $args);
       $this->setValue($items[$entity_id][0]);
diff --git a/core/modules/field/field.views.inc b/core/modules/field/field.views.inc
index 7def00e..93cceeb 100644
--- a/core/modules/field/field.views.inc
+++ b/core/modules/field/field.views.inc
@@ -145,20 +145,20 @@ function field_views_field_default_views_data(FieldInterface $field) {
 
   // Description of the field tables.
   $field_tables = array(
-    EntityStorageControllerInterface::FIELD_LOAD_CURRENT => array(
+    EntityStorageControllerInterface::LOAD_CURRENT => array(
       'table' => FieldableDatabaseStorageController::_fieldTableName($field),
       'alias' => "{$entity_type}__{$field_name}",
     ),
   );
   if ($supports_revisions) {
-    $field_tables[EntityStorageControllerInterface::FIELD_LOAD_REVISION] = array(
+    $field_tables[EntityStorageControllerInterface::LOAD_REVISION] = array(
       'table' => FieldableDatabaseStorageController::_fieldRevisionTableName($field),
       'alias' => "{$entity_type}_revision__{$field_name}",
     );
   }
 
   // Build the relationships between the field table and the entity tables.
-  $table_alias = $field_tables[EntityStorageControllerInterface::FIELD_LOAD_CURRENT]['alias'];
+  $table_alias = $field_tables[EntityStorageControllerInterface::LOAD_CURRENT]['alias'];
   $data[$table_alias]['table']['join'][$entity_table] = array(
     'left_field' => $entity_info['entity_keys']['id'],
     'field' => 'entity_id',
@@ -167,7 +167,7 @@ function field_views_field_default_views_data(FieldInterface $field) {
     ),
   );
   if ($supports_revisions) {
-    $table_alias = $field_tables[EntityStorageControllerInterface::FIELD_LOAD_REVISION]['alias'];
+    $table_alias = $field_tables[EntityStorageControllerInterface::LOAD_REVISION]['alias'];
     $data[$table_alias]['table']['join'][$entity_revision_table] = array(
       'left_field' => $entity_info['entity_keys']['revision'],
       'field' => 'revision_id',
@@ -195,7 +195,7 @@ function field_views_field_default_views_data(FieldInterface $field) {
     $table = $table_info['table'];
     $table_alias = $table_info['alias'];
 
-    if ($type == EntityStorageControllerInterface::FIELD_LOAD_CURRENT) {
+    if ($type == EntityStorageControllerInterface::LOAD_CURRENT) {
       $group = $group_name;
       $field_alias = $field_name;
     }
@@ -216,7 +216,7 @@ function field_views_field_default_views_data(FieldInterface $field) {
     $aliases = array();
     $also_known = array();
     foreach ($all_labels as $label_name => $true) {
-      if ($type == EntityStorageControllerInterface::FIELD_LOAD_CURRENT) {
+      if ($type == EntityStorageControllerInterface::LOAD_CURRENT) {
         if ($label != $label_name) {
           $aliases[] = array(
             'base' => $entity_table,
@@ -255,7 +255,7 @@ function field_views_field_default_views_data(FieldInterface $field) {
       'entity_tables' => $entity_tables,
       // Default the element type to div, let the UI change it if necessary.
       'element type' => 'div',
-      'is revision' => $type == EntityStorageControllerInterface::FIELD_LOAD_REVISION,
+      'is revision' => $type == EntityStorageControllerInterface::LOAD_REVISION,
     );
   }
 
@@ -301,7 +301,7 @@ function field_views_field_default_views_data(FieldInterface $field) {
       $table = $table_info['table'];
       $table_alias = $table_info['alias'];
 
-      if ($type == EntityStorageControllerInterface::FIELD_LOAD_CURRENT) {
+      if ($type == EntityStorageControllerInterface::LOAD_CURRENT) {
         $group = $group_name;
       }
       else {
diff --git a/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php b/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
index 6c6b350..32a7c19 100644
--- a/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
+++ b/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
@@ -229,7 +229,7 @@ public function query($use_groupby = FALSE) {
       $options += is_array($this->options['group_columns']) ? $this->options['group_columns'] : array();
 
       $fields = array();
-      $rkey = $this->definition['is revision'] ? EntityStorageControllerInterface::FIELD_LOAD_REVISION : EntityStorageControllerInterface::FIELD_LOAD_CURRENT;
+      $rkey = $this->definition['is revision'] ? EntityStorageControllerInterface::LOAD_REVISION : EntityStorageControllerInterface::LOAD_CURRENT;
       // Go through the list and determine the actual column name from field api.
       foreach ($options as $column) {
         $name = $column;
diff --git a/core/modules/file/file.module b/core/modules/file/file.module
index 4041886..9e656e3 100644
--- a/core/modules/file/file.module
+++ b/core/modules/file/file.module
@@ -618,7 +618,7 @@ function file_file_download($uri, $field_type = 'file') {
   }
 
   // Find out which (if any) fields of this type contain the file.
-  $references = file_get_file_references($file, NULL, EntityStorageControllerInterface::FIELD_LOAD_CURRENT, $field_type);
+  $references = file_get_file_references($file, NULL, EntityStorageControllerInterface::LOAD_CURRENT, $field_type);
 
   // Stop processing if there are no references in order to avoid returning
   // headers for files controlled by other modules. Make an exception for
@@ -1828,9 +1828,9 @@ function file_icon_map(File $file) {
  *   reference check to the given field.
  * @param $age
  *   (optional) A constant that specifies which references to count. Use
- *   EntityStorageControllerInterface::FIELD_LOAD_REVISION to retrieve all
+ *   EntityStorageControllerInterface::LOAD_REVISION to retrieve all
  *   references within all revisions or
- *   EntityStorageControllerInterface::FIELD_LOAD_CURRENT to retrieve references
+ *   EntityStorageControllerInterface::LOAD_CURRENT to retrieve references
  *   only in the current revisions.
  * @param $field_type
  *   (optional) The name of a field type. If given, limits the reference check
@@ -1842,7 +1842,7 @@ function file_icon_map(File $file) {
  *   A multidimensional array. The keys are field_name, entity_type,
  *   entity_id and the value is an entity referencing this file.
  */
-function file_get_file_references(File $file, $field = NULL, $age = EntityStorageControllerInterface::FIELD_LOAD_REVISION, $field_type = 'file') {
+function file_get_file_references(File $file, $field = NULL, $age = EntityStorageControllerInterface::LOAD_REVISION, $field_type = 'file') {
   $references = &drupal_static(__FUNCTION__, array());
   $field_columns = &drupal_static(__FUNCTION__ . ':field_columns', array());
 
@@ -1856,7 +1856,7 @@ function file_get_file_references(File $file, $field = NULL, $age = EntityStorag
       // The usage table contains usage of every revision. If we are looking
       // for every revision or the entity does not support revisions then
       // every usage is already a match.
-      $match_entity_type = $age == EntityStorageControllerInterface::FIELD_LOAD_REVISION || !isset($entity_info['entity_keys']['revision']);
+      $match_entity_type = $age == EntityStorageControllerInterface::LOAD_REVISION || !isset($entity_info['entity_keys']['revision']);
       $entities = entity_load_multiple($entity_type, array_keys($entity_ids));
       foreach ($entities as $entity) {
         $bundle = $entity->bundle();
diff --git a/core/modules/system/lib/Drupal/system/Tests/Entity/EntityQueryTest.php b/core/modules/system/lib/Drupal/system/Tests/Entity/EntityQueryTest.php
index e0463f6..62f2030 100644
--- a/core/modules/system/lib/Drupal/system/Tests/Entity/EntityQueryTest.php
+++ b/core/modules/system/lib/Drupal/system/Tests/Entity/EntityQueryTest.php
@@ -252,7 +252,7 @@ function testEntityQuery() {
     $this->assertResult();
     $this->queryResults = $this->factory->get('entity_test_mulrev')
       ->condition("$greetings.value", 'merhaba')
-      ->age(EntityStorageControllerInterface::FIELD_LOAD_REVISION)
+      ->age(EntityStorageControllerInterface::LOAD_REVISION)
       ->sort('revision_id')
       ->execute();
     // Bit 2 needs to be set.
@@ -282,7 +282,7 @@ function testEntityQuery() {
     $this->assertIdentical($results, array_slice($assert, 4, 8, TRUE));
     $results = $this->factory->get('entity_test_mulrev')
       ->condition("$greetings.value", 'a', 'ENDS_WITH')
-      ->age(EntityStorageControllerInterface::FIELD_LOAD_REVISION)
+      ->age(EntityStorageControllerInterface::LOAD_REVISION)
       ->sort('id')
       ->execute();
     // Now we get everything.

diff --git a/core/lib/Drupal/Core/Entity/FieldableEntityStorageControllerBase.php b/core/lib/Drupal/Core/Entity/FieldableEntityStorageControllerBase.php
index b89625d..baf68a1 100644
--- a/core/lib/Drupal/Core/Entity/FieldableEntityStorageControllerBase.php
+++ b/core/lib/Drupal/Core/Entity/FieldableEntityStorageControllerBase.php
@@ -33,17 +33,17 @@ protected function loadFieldItems(array $entities) {
       return;
     }
 
-    $age = static::FIELD_LOAD_CURRENT;
+    $age = static::LOAD_CURRENT;
     foreach ($entities as $entity) {
       if (!$entity->isDefaultRevision()) {
-        $age = static::FIELD_LOAD_REVISION;
+        $age = static::LOAD_REVISION;
         break;
       }
     }
 
     // Only the most current revision of non-deleted fields for cacheable entity
     // types can be cached.
-    $load_current = $age == static::FIELD_LOAD_CURRENT;
+    $load_current = $age == static::LOAD_CURRENT;
     $info = entity_get_info($this->entityType);
     $use_cache = $load_current && $info['field_cache'];
 
@@ -177,9 +177,9 @@ protected function deleteFieldItemsRevision(EntityInterface $entity) {
    * @param array $entities
    *   An array of entities keyed by entity ID.
    * @param int $age
-   *   EntityStorageControllerInterface::FIELD_LOAD_CURRENT to load the most
+   *   EntityStorageControllerInterface::LOAD_CURRENT to load the most
    *   recent revision for all fields, or
    *   EntityStorageControllerInterface::FIELD_LOAD_REVISION to load the version
    *   indicated by each entity.
    */
   abstract protected function doLoadFieldItems($entities, $age);
@@ -177,9 +177,9 @@ protected function deleteFieldItemsRevision(EntityInterface $entity) {
    *   recent revision for all fields, or
-   *   EntityStorageControllerInterface::FIELD_LOAD_REVISION to load the version
+   *   EntityStorageControllerInterface::LOAD_REVISION to load the version
    *   indicated by each entity.
    */
diff --git a/core/lib/Drupal/Core/Entity/Query/QueryBase.php b/core/lib/Drupal/Core/Entity/Query/QueryBase.php
index 9122bab..dabf7c3 100644
--- a/core/lib/Drupal/Core/Entity/Query/QueryBase.php
+++ b/core/lib/Drupal/Core/Entity/Query/QueryBase.php
@@ -102,12 +102,12 @@
   /**
    * Flag indicating whether to query the current revision or all revisions.
    *
    * Can be either EntityStorageControllerInterface::FIELD_LOAD_CURRENT or
    * EntityStorageControllerInterface::FIELD_LOAD_REVISION.
    *
    * @var string
    */
-  protected $age = EntityStorageControllerInterface::FIELD_LOAD_CURRENT;
+  protected $age = EntityStorageControllerInterface::LOAD_CURRENT;
 
   /**
    * The query pager data.
@@ -244,7 +244,7 @@ public function accessCheck($access_check = TRUE) {
   /**
    * Implements \Drupal\Core\Entity\Query\QueryInterface::age().
    */
-  public function age($age = EntityStorageControllerInterface::FIELD_LOAD_CURRENT) {
+  public function age($age = EntityStorageControllerInterface::LOAD_CURRENT) {
     $this->age = $age;
     return $this;
   }
@@ -102,12 +102,12 @@
    * Flag indicating whether to query the current revision or all revisions.
    *
-   * Can be either EntityStorageControllerInterface::FIELD_LOAD_CURRENT or
-   * EntityStorageControllerInterface::FIELD_LOAD_REVISION.
+   * Can be either EntityStorageControllerInterface::LOAD_CURRENT or
+   * EntityStorageControllerInterface::LOAD_REVISION.
    *
    * @var string